==> angela-client-internal-3.2.8-sources.jar: org/terracotta/angela/client/config/custom/CustomTmsConfigurationContext.java <==
/*
 * Copyright Terracotta, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.terracotta.angela.client.config.custom;

import org.terracotta.angela.client.config.TmsConfigurationContext;
import org.terracotta.angela.common.TerracottaCommandLineEnvironment;
import org.terracotta.angela.common.distribution.Distribution;
import org.terracotta.angela.common.tcconfig.License;
import org.terracotta.angela.common.tms.security.config.TmsServerSecurityConfig;
import org.terracotta.angela.common.util.IpUtils;

public class CustomTmsConfigurationContext implements TmsConfigurationContext {
  private Distribution distribution;
  private License license;
  private String hostname = IpUtils.getHostName();
  private TmsServerSecurityConfig securityConfig;
  private TerracottaCommandLineEnvironment terracottaCommandLineEnvironment = TerracottaCommandLineEnvironment.DEFAULT;

  protected CustomTmsConfigurationContext() {
  }

  @Override
  public Distribution getDistribution() {
    return distribution;
  }

  public CustomTmsConfigurationContext distribution(Distribution distribution) {
    this.distribution = distribution;
    return this;
  }

  @Override
  public License getLicense() {
    return license;
  }

  public CustomTmsConfigurationContext license(License license) {
    this.license = license;
    return this;
  }

  @Override
  public String getHostname() {
    return hostname;
  }

  public CustomTmsConfigurationContext hostname(String serverName) {
    this.hostname = serverName;
    return this;
  }

  @Override
  public TmsServerSecurityConfig getSecurityConfig() {
    return securityConfig;
  }

  public CustomTmsConfigurationContext securityConfig(TmsServerSecurityConfig securityConfig) {
    this.securityConfig = securityConfig;
    return this;
  }

  @Override
  public TerracottaCommandLineEnvironment getTerracottaCommandLineEnvironment() {
    return terracottaCommandLineEnvironment;
  }

  public CustomTmsConfigurationContext terracottaCommandLineEnvironment(TerracottaCommandLineEnvironment terracottaCommandLineEnvironment) {
    this.terracottaCommandLineEnvironment = terracottaCommandLineEnvironment;
    return this;
  }
}

==> angela-client-internal-3.3.38-sources.jar: org/terracotta/angela/client/config/custom/CustomTmsConfigurationContext.java <==
/*
 * Copyright Terracotta, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.terracotta.angela.client.config.custom;

import org.terracotta.angela.client.config.TmsConfigurationContext;
import org.terracotta.angela.common.TerracottaCommandLineEnvironment;
import org.terracotta.angela.common.distribution.Distribution;
import org.terracotta.angela.common.tcconfig.License;
import org.terracotta.angela.common.tms.security.config.TmsServerSecurityConfig;
import org.terracotta.angela.common.util.IpUtils;

public class CustomTmsConfigurationContext implements TmsConfigurationContext {
  private Distribution distribution;
  private License license;
  private String hostname = IpUtils.getHostName();
  private TmsServerSecurityConfig securityConfig;
  private TerracottaCommandLineEnvironment terracottaCommandLineEnvironment = TerracottaCommandLineEnvironment.DEFAULT;

  protected CustomTmsConfigurationContext() {
  }

  @Override
  public Distribution getDistribution() {
    return distribution;
  }

  public CustomTmsConfigurationContext distribution(Distribution distribution) {
    this.distribution = distribution;
    return this;
  }

  @Override
  public License getLicense() {
    return license;
  }

  public CustomTmsConfigurationContext license(License license) {
    this.license = license;
    return this;
  }

  @Override
  public String getHostName() {
    return hostname;
  }

  public CustomTmsConfigurationContext hostname(String serverName) {
    this.hostname = serverName;
    return this;
  }

  @Override
  public TmsServerSecurityConfig getSecurityConfig() {
    return securityConfig;
  }

  public CustomTmsConfigurationContext securityConfig(TmsServerSecurityConfig securityConfig) {
    this.securityConfig = securityConfig;
    return this;
  }

  @Override
  public TerracottaCommandLineEnvironment getTerracottaCommandLineEnvironment() {
    return terracottaCommandLineEnvironment;
  }

  public CustomTmsConfigurationContext terracottaCommandLineEnvironment(TerracottaCommandLineEnvironment terracottaCommandLineEnvironment) {
    this.terracottaCommandLineEnvironment = terracottaCommandLineEnvironment;
    return this;
  }
}
